@@ -15,6 +15,7 @@ void GIBBS_sumpred_gpp(int *aggtype, int *cov, int *spdecay, double *flag,
      int *its, int *burnin,
      int *n, int *m, int *T, int *r, int *rT, int *p, int *N, int *report,
      double *shape_e, double *shape_eta, double *shape_l,  
+     double *phi_a, double *phi_b,
      double *prior_a, double *prior_b, double *mu_beta, double *delta2_beta,
      double *mu_rho,  double *delta2_rho, double *alpha_l, double *delta2_l,
      double *phi, double *tau, double *phis, int *phik,
@@ -130,7 +131,9 @@ void GIBBS_sumpred_gpp(int *aggtype, int *cov, int *spdecay, double *flag,
      for(i=0; i < its1; i++) {
 
      JOINT_onephi_gpp(cov, spdecay, flag, n, m, T, r, rT, p, N, 
-     shape_e, shape_eta, shape_l, prior_a, prior_b, mu_beta, delta2_beta, 
+     shape_e, shape_eta, shape_l, 
+     phi_a, phi_b,
+     prior_a, prior_b, mu_beta, delta2_beta, 
      mu_rho, delta2_rho, alpha_l, delta2_l, phi1, tau, phis, phik, nu, dm, dnm, 
      constant, sig2e1, sig2eta1, sig2l, beta1, rho1, mu_l, X, z, w0, w, 
      phip, acc, nup, sig2ep, sig2etap, betap, rhop, mu_lp, sig2lp, w0p, wp, zfit);
@@ -317,6 +320,7 @@ void GIBBS_sumpred_gpp(int *aggtype, int *cov, int *spdecay, double *flag,
 void GIBBS_zfitsum_onephi_gpp(int *cov, int *spdecay, double *flag, int *its, int *burnin,
      int *n, int *m, int *T, int *r, int *rT, int *p, int *N, int *report,
      double *shape_e, double *shape_eta, double *shape_l,  
+     double *phi_a, double *phi_b,
      double *prior_a, double *prior_b, double *mu_beta, double *delta2_beta,
      double *mu_rho,  double *delta2_rho, double *alpha_l, double *delta2_l,
      double *phi_eta, double *tau_eta, double *phis, int *phik, 
@@ -418,7 +422,9 @@ void GIBBS_zfitsum_onephi_gpp(int *cov, int *spdecay, double *flag, int *its, in
      for(i=0; i < its1; i++) {
 
      JOINT_onephi_gpp(cov, spdecay, flag, n, m, T, r, rT, p, N, 
-     shape_e, shape_eta, shape_l, prior_a, prior_b, mu_beta, delta2_beta, 
+     shape_e, shape_eta, shape_l, 
+     phi_a, phi_b,
+     prior_a, prior_b, mu_beta, delta2_beta, 
      mu_rho, delta2_rho, alpha_l, delta2_l, phi_eta1, tau_eta, phis, phik, nu, 
      dm, dnm, constant, sig2e1, sig2eta1, sig2l1, beta1, rho1, mu_l1, X, z, 
      w0, w, phi_etap, acc_eta, nup, sig2ep, sig2etap, betap, rhop, mu_lp, sig2lp, 
