@@ -8,7 +8,8 @@
 
 void GIBBS_sumpred_txt_gp(int *aggtype, double *flag, int *its, int *burnin,
      int *n, int *T, int *r, int *rT, int *p, int *N, int *report,
-     int *cov, int *spdecay, double *shape_e, double *shape_eta,  
+     int *cov, int *spdecay, double *shape_e, double *shape_eta,
+     double *phi_a, double *phi_b,  
      double *prior_a, double *prior_b, double *prior_mubeta, 
      double *prior_sigbeta, double *prior_omu, double *prior_osig,
      double *phi, double *tau, double *phis, int *phik,
@@ -19,7 +20,8 @@ void GIBBS_sumpred_txt_gp(int *aggtype, double *flag, int *its, int *burnin,
 
 void GIBBS_gp(double *flag, int *its, int *burnin,
      int *n, int *T, int *r, int *rT, int *p, int *N, int *report,
-     int *cov, int *spdecay, double *shape_e, double *shape_eta,   
+     int *cov, int *spdecay, double *shape_e, double *shape_eta,
+     double *phi_a, double *phi_b,   
      double *prior_a, double *prior_b, double *prior_mubeta, 
      double *prior_sigbeta, double *prior_omu, double *prior_osig,
      double *phi, double *tau, double *phis, int *phik,
@@ -78,6 +80,7 @@ void GIBBSsptp_gp(int *intercept, double *flag, int *its, int *burnin,
 
 void JOINT_gp(int *n, int *T, int *r, int *rT, int *p, int *N, 
      int *cov, int *spdecay, double *shape_e, double *shape_eta,
+     double *phi_a, double *phi_b,
      double *prior_a, double *prior_b, double *prior_mubeta, 
      double *prior_sigbeta, double *prior_omu, double *prior_osig,
      double *phi, double *tau, double *phis, int *phik, double *nu,
